#!/usr/bin/env node

const program = require('commander');
const package = require('./package.json');
const chalk = require('chalk');
const list = require('./bin/list');
const init = require('./bin/init');
const cleanToken = require('./bin/cleanToken');
const figlet = require('figlet');
const PACKAGE = require('./package');
const minimist = require('minimist');
const semver = require('semver');
const templates = require('./lib/templates.js');

/**
 * Print banner
 * Font preview：http://patorjk.com/software/taag/#p=display&f=3D-ASCII&t=feflow%0A
 *
 */
function printBanner() {
  console.log(chalk.green(figlet.textSync('aif-tool', {
    font: '3D-ASCII',
    horizontalLayout: 'default',
    verticalLayout: 'default',
  })));

  // 执行任意命令将配置缓存到客户本地
  templates.getAifToolConfig();

  console.log(chalk.green(
    `  AIF-TOOL(阿尔法), 当前版本v${PACKAGE.version}, 让开发工作流程更简单, 主页: https://tta.tongdun.me/detail/305`));
  console.log(chalk.green('  (c) powered by AIF Team.'));
  console.log(chalk.green('  Author:yun.zhao(178518@gmail.com)'));
  console.log(chalk.green('  Run aif-tool --help to see usage.'));
}

printBanner();

program.version(chalk.green('  ' + (package.name).toUpperCase() + ' v' + package.version), '-v, --version').
  usage('<command> [options]');

program.command('init').description(chalk.green('创建新新项目')).alias('i').action((name) => {
  init(name);
});

program.command('list').description(chalk.green('显示可使用的模板列表')).alias('l').action(() => {
  list();
});

program.command('cleanToken').description(chalk.green('Gitlab认证重置,域账户密码修改时候会用到')).alias('ct').action(() => {
  cleanToken();
});

program.parse(process.argv);

if (program.args.length == 0) {
  //这里是处理默认没有输入参数或者命令的时候，显示help信息
  program.help();
}
