const co = require('co')
const Promise = require('bluebird')
const NodeCmd = require('node-cmd')

/**
 * gitlab地址,组默认为TDEF,默认为Public,project权限为MASTER
 * GUEST     = 10
 * REPORTER  = 20
 * DEVELOPER = 30
 * MASTER    = 40
 * OWNER     = 50 project 不能是owner
 */
const GITLABURL = 'https://gitlab.fraudmetrix.cn/api/v3'
const TDFEGROUPID = 404
const VISIBILITYLEVEL = 20
const ACCESSLEVEL = 40

/**
 * 执行shell 登录gitlab
 *
 * @param username 用户名
 * @param password 密码
 */
const getSession = function (userName, password) {
  return new Promise(function (resolve, reject) {
    NodeCmd.get(`curl -d "login=${userName}&password=${password}" ${GITLABURL}/session`,
      function (err, data) {
        if (!err) {
          resolve(JSON.parse(data))
        } else {
          reject(err)
        }
      },
    )
  })
}

/**
 * 执行shell 创建project
 *
 * @param userInfo 用户信息
 */
const createNewProject = function (userInfo, projectInfo) {
  return new Promise(function (resolve, reject) {
    NodeCmd.get(
      `curl -d "name=${projectInfo.name}&namespace_id=${TDFEGROUPID}&description=${projectInfo.desc}&visibility_level=${VISIBILITYLEVEL}" ${GITLABURL}/projects?private_token=${userInfo.private_token}`,
      function (err, data) {
        if (!err) {
          resolve(JSON.parse(data))
        } else {
          reject(err)
        }
      },
    )
  })
}

/**
 * 执行shell 创建用户
 * @param userInfo
 * @param project
 */
const addProjectMember = function (userInfo, project) {
  return new Promise(function (resolve, reject) {
    NodeCmd.get(
      `curl -d "id=${project.id}&user_id=${userInfo.id}&access_level=${ACCESSLEVEL}" ${GITLABURL}/projects/${project.id}/members?private_token=${userInfo.private_token}`,
      function (err, data) {
        if (!err) {
          resolve(JSON.parse(data))
        } else {
          reject(err)
        }
      },
    )
  })
}


// generator 实现了状态暂停/函数暂停 —— 通过 yield 关键字暂停函数，并返回当前函数的状态。
module.exports = {
  getSession,
  createNewProject,
  addProjectMember
}

// 异步的代码 "同步化"
co(function * () {
  //const userInfo = yield getSession('***', '***')

  //console.log(userInfo.message);

  //const project = yield createNewProject(userInfo,{name:'yunTest',desc:'yunTest'})

  //yield addProjectMember(userInfo, project)
})
